Branching Tree — ecyglpki 0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- ecyglpki 0.1.0 documentation »

# Branching Tree

class `ecyglpki.` `Tree`

  A GLPK search tree

  `ios_add_row`(str name, str rowclass, coeffs, str vartype, double rhs)

    Add row (constraint) to the cut pool

  `ios_best_node`()

    Find active subproblem with best local bound

  `ios_branch_upon`(col, str branchdir)

    Choose variable to branch upon

  `ios_can_branch`(col)

    Check if can branch upon specified variable

  `ios_clear_pool`()

    Remove all rows (constraints) from the cut pool

  `ios_curr_node`()

    Determine current active subproblem

  `ios_del_row`(int row)

    Remove row (constraint) from the cut pool

  `ios_first_node`()

    Determine first active subproblem

  `ios_heur_sol`(coeffs)

    Provide solution found by heuristic

  `ios_last_node`()

    Determine last active subproblem

  `ios_mip_gap`()

    Compute relative MIP gap

  `ios_next_node`(int node)

    Determine next active subproblem

  `ios_node_bound`(int node)

    Determine subproblem local bound

  `ios_node_data`(int node)

    Access subproblem application-specific data

  `ios_node_level`(int node)

    Determine subproblem level

  `ios_pool_size`()

    Determine current size of the cut pool

  `ios_prev_node`(int node)

    Determine previous active subproblem

  `ios_reason`()

    Determine reason for calling the callback routine

  `ios_row_attr`(row)

    Retrieve additional row attributes

  `ios_select_node`(int node)

    Select subproblem to continue the search

  `ios_terminate`()

    Terminate the solution process

  `ios_tree_size`()

    Determine size of the branch-and-bound tree

  `ios_up_node`(int node)

    Determine parent subproblem

  `problem`

### Navigation

- index
- modules |
- next |
- previous |
- ecyglpki 0.1.0 documentation »